@@ -32,24 +32,24 @@ def GetInductParams(inductOtype, cLevels, dftC, cFmt):
     # Inductogram calculation and plot settings
     InductParams.colorType = 'zb'  # What parameter to use for color of points in phase space plots. Options are "Tmean", "zb".
     InductParams.SPECIFIC_CLEVELS = True  # Whether to use the specific cLevels listed below (in GetClevels) or use default numbers
-    InductParams.excSelectionCalc = {'synodic': True, 'orbital': True, 'true anomaly': True,  'synodic harmonic': True, 'synodic 2nd harmonic': True,  'synodic-TA slow beat': True,  'synodic-TA fast beat': True}  # Which magnetic excitations to include in calculations
-    InductParams.excSelectionPlot = {'synodic': True, 'orbital': True, 'true anomaly': False, 'synodic harmonic': True, 'synodic 2nd harmonic': False, 'synodic-TA slow beat': False, 'synodic-TA fast beat': False}  # Which magnetic excitations to include in plotting
-    InductParams.nwPts = 80  # Resolution for salinity values in ocean salinity vs. other plots
+    InductParams.excSelectionCalc = {'synodic':  True, 'orbital':  True, 'true anomaly':  True, 'synodic harmonic':  True, 'synodic 2nd harmonic':  True, 'synodic-TA slow beat':  True, 'synodic-TA fast beat':  True}  # Which magnetic excitations to include in calculations
+    InductParams.excSelectionPlot = {'synodic':  True, 'orbital':  True, 'true anomaly':  True, 'synodic harmonic':  True, 'synodic 2nd harmonic': False, 'synodic-TA slow beat': False, 'synodic-TA fast beat': False}  # Which magnetic excitations to include in plotting
+    InductParams.nwPts = 40  # Resolution for salinity values in ocean salinity vs. other plots
     InductParams.wMin = {'Europa': np.log10(1)}
-    InductParams.wMax = {'Europa': np.log10(100)}
-    InductParams.nTbPts = 60  # Resolution for Tb values in ocean salinity/Tb plots
+    InductParams.wMax = {'Europa': np.log10(35)}
+    InductParams.nTbPts = 30  # Resolution for Tb values in ocean salinity/Tb plots
     InductParams.TbMin = {'Europa': 262.0}
     InductParams.TbMax = {'Europa': 267.0}
-    InductParams.nphiPts = 60  # Resolution for phiRockMax values in ocean salinity/phiMax plots
+    InductParams.nphiPts = 30  # Resolution for phiRockMax values in ocean salinity/phiMax plots
     InductParams.phiMin = {'Europa': np.log10(0.01)}
     InductParams.phiMax = {'Europa': np.log10(0.75)}
-    InductParams.nrhoPts = 100  # Resolution for silicate density values in ocean salinity/rho plots
+    InductParams.nrhoPts = 50  # Resolution for silicate density values in ocean salinity/rho plots
     InductParams.rhoMin = {'Europa': 3300}
     InductParams.rhoMax = {'Europa': 3700}
-    InductParams.nSigmaPts = 80  # Resolution for conductivity values in ocean conductivity/thickness plots
+    InductParams.nSigmaPts = 40  # Resolution for conductivity values in ocean conductivity/thickness plots
     InductParams.sigmaMin = {'Europa': np.log10(1e-1)}
     InductParams.sigmaMax = {'Europa': np.log10(1e2)}
-    InductParams.nDpts = 90  # Resolution for ocean thickness as for conductivity
+    InductParams.nDpts = 50  # Resolution for ocean thickness as for conductivity
     InductParams.Dmin = {'Europa': np.log10(1e0)}
     InductParams.Dmax = {'Europa': np.log10(2e2)}
     InductParams.zbFixed_km = {'Europa': 20}
