@@ -4,7 +4,7 @@ import spiceypy as spice
 from PlanetProfile.Utilities.defineStructs import ColorStruct, StyleStruct, \
     FigLblStruct, FigSizeStruct, FigMiscStruct
 
-configPlotsVersion = 10  # Integer number for config file version. Increment when new settings are added to the default config file.
+configPlotsVersion = 11  # Integer number for config file version. Increment when new settings are added to the default config file.
 Color = ColorStruct()
 Style = StyleStruct()
 FigLbl = FigLblStruct()
@@ -14,12 +14,14 @@ FigMisc = FigMiscStruct()
 """ Figure color options """
 Color.Induction = {'synodic': 'blue', 'orbital': 'purple', 'true anomaly': 'green', 'synodic harmonic': 'goldenrod'}  # Colors for inductOgram plots
 Color.ref = 'gray'
-Color.geotherm = 'white'
+Color.geothermHydro = 'yellow'
+Color.geothermInner = 'white'
 Color.BdipInset = 'black'  # Color for inset box of surface induced dipole strength plots
 
 # Wedge diagram color options
 Color.none = '#FFFFFF00'
 Color.wedgeBd = 'black'
+Color.wedgeMarkRadii = 'black'
 Color.ionoCmapName = 'RdPu'
 Color.ionoTop = 0.0
 Color.ionoBot = 0.2
@@ -59,7 +61,12 @@ Color.paleSilCondCmapName = 'terrain'
 Color.paleSilCondTop = 0.78 - 0.001
 Color.paleSilCondBot = 0.78
 
-# PvT properties colormaps
+# PvThydro properties colormaps
+Color.PvThydroCmapName = 'Blues'
+Color.PvThydroHi = 1.0
+Color.PvThydroLo = 0.2
+
+# PvTPerpleX properties colormaps
 Color.PvTsilCmapName = 'copper'
 Color.PvTsilHi = 1.0
 Color.PvTsilLo = 0.0
@@ -156,6 +163,8 @@ Style.LW_wedgeMajor = 0.375  # Linewidth in pt for major layer boundaries in wed
 Style.TS_ticks = 12  # Text size in pt for tick marks on radius scale
 Style.TS_desc = 14  # Text size in pt for model description and label
 Style.TS_super = 16  # Text size in pt for overall ("suptitle") label with multiple wedges
+Style.LS_markRadii = '--'  # Linestyle for radii mark line when toggled on
+Style.LW_markRadii = 0.375  # Linewidth for radii mark line when toggled on
 
 # Complex dipole plots
 Style.MW_dip = {'synodic': 5, 'orbital': 6, 'true anomaly': 6, 'synodic harmonic': 4.5}  # Marker size for each period in complex dipole plots
@@ -185,7 +194,7 @@ FigLbl.NAN_FOR_EMPTY = False  # Whether to use nan (or -) for empty layer parame
 FigLbl.PFULL_IN_GPa = True  # Whether to plot P in GPa (or MPa) for full-body plots
 FigLbl.PHYDRO_IN_bar = False  # Whether to print P in bar (or MPa) for hydrosphere plots
 FigLbl.w_IN_WTPCT = False  # Whether to print salinities in wt% (or g/kg) in tables
-FigLbl.T_IN_C = False  # Whether to print T in °C (or K) in plots
+FigLbl.T_IN_C = False  # Whether to print T in deg C (or K) in plots
 FigLbl.x_IN_MOLPCT = True  # Whether to print silicate/core mass fractions in mol% (or fractional) in tables and plots
 FigLbl.qSURF_IN_mW = True  # Whether to print qSurf in mW/m^2 (or W/m^2)
 FigLbl.phi_IN_VOLPCT = False  # Whether to print porosity (phi) in vol% (or unitless volume fraction)
@@ -204,6 +213,7 @@ FigSize.vmant = (6, 6)
 FigSize.vcore = (6, 6)
 FigSize.vpvt = (12, 6)
 FigSize.vwedg = (4.5, 4.5)
+FigSize.vphase = (5, 6)
 FigSize.explore = (6, 4)
 FigSize.phaseSpaceSolo = (6, 4)
 FigSize.phaseSpaceCombo = (9, 4)
@@ -235,6 +245,8 @@ FigMisc.SCALE_HYDRO_LW = True  # Whether to adjust thickness of lines on hydrosp
 FigMisc.MANUAL_HYDRO_COLORS = True  # Whether to set color of lines in hydrosphere according to melting temperature
 FigMisc.RELATIVE_Tb_K = True  # Whether to set colormap of lines based on relative comparison (or fixed settings in ColorStruct)
 FigMisc.TminHydro = 200  # Minimum temperature to display on hydrosphere plots
+FigMisc.PHASE_LABELS = True  # Whether to print phase labels on density plots
+FigLbl.TS_hydroLabels = 18  # Font size for hydrosphere phase labels in pt
 
 # Wedge diagrams
 FigMisc.IONOSPHERE_IN_WEDGE = False  # Whether to include specified ionosphere in wedge diagram
@@ -244,6 +256,17 @@ FigMisc.DRAW_CONVECTION_BOUND = False  # Whether to draw a boundary line between
 FigMisc.DRAW_POROUS_BOUND = False  # Whether to draw a boundary line between porous and non-porous materials
 FigMisc.DRAW_FeS_BOUND = True  # Whether to draw a boundary line between Fe and FeS in the core
 FigMisc.minzbRratio_frac = 0.05  # Fraction of total body radius for ice shell and ocean thickness, above which ice shell ticks will automatically switch on (overrides WEDGE_ICE_TICKS)
+FigMisc.MARK_RADII = True  # Whether to add a marker line from radius labels to layer arc
+
+# Hydrosphere PT diagrams
+FigMisc.PT_RASTER = True  # Whether to rasterize gridded information in PT plots and phase diagrams. Dramatically speeds up figure creation time and reduces file size, but renders gridded data grainy upon zoom-in. 
+FigMisc.nTphase = 240  # Number of temperature points to evaluate/plot for hydrosphere phase diagram. If None, use geotherm (Planet.P_MPa) for the phase diagram.
+FigMisc.nPphase = 360  # Number of pressure points to evaluate/plot for hydrosphere phase diagram. If None, use geotherm (Planet.T_K) for the phase diagram.
+FigMisc.nThydro = 160  # Number of temperature points to evaluate/plot for PT property plots
+FigMisc.nPhydro = 200  # Number of pressure points to evaluate/plot for PT property plots
+FigMisc.PminHydro_MPa = 0.1  # Minimum pressure to use for hydrosphere and phase diagram PT plots in MPa
+FigMisc.TminHydro_K = 220  # Minimum temperature to use for hydrosphere and phase diagram PT plots in K
+FigLbl.hydroPhaseSize = 14  # Font size of label for phase in phase diagram
 
 # Silicate/core PT diagrams
 FigMisc.nTgeo = 80  # Number of temperature points to evaluate/plot for PT property plots
